==> ejc-zdsmaterialb-impl-3.0.0-20251028.071157-70-sources.jar: com/ejianc/business/zdsmaterial/erp/bean/ContractManagerEntity.java <==
package com.ejianc.business.zdsmaterial.erp.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 合同负责人实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_material_erp_contract_manager")
public class ContractManagerEntity extends BaseEntity {

    private static final long serialVersionUID = -2800505942360815904L;

    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="modify_user_name")
    private String modifyUserName; // 修改人名称
    @TableField(value="contract_type")
    private String contractType; // 1-采购合同，2-分包合同
    @TableField(value="contract_id")
    private Long contractId; // 合同ID
    @TableField(value="contract_sid")
    private String contractSid; // 合同SID
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_sid")
    private String projectSid; // 项目SID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="operator_id")
    private Long operatorId; // 履约负责人ID
    @TableField(value="operator_code")
    private String operatorCode; // 履约负责人工号
    @TableField(value="operator_sid")
    private String operatorSid; // 履约负责人SID
    @TableField(value="operator_name")
    private String operatorName; // 履约负责人名称
    @TableField(value="settler_id")
    private Long settlerId; // 结算负责人ID
    @TableField(value="settler_code")
    private String settlerCode; // 结算负责人工号
    @TableField(value="settler_sid")
    private String settlerSid; // 结算负责人SID
    @TableField(value="settler_name")
    private String settlerName; // 结算负责人名称
    
    
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractSid() {
        return contractSid;
    }

    public void setContractSid(String contractSid) {
        this.contractSid = contractSid;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectSid() {
        return projectSid;
    }

    public void setProjectSid(String projectSid) {
        this.projectSid = projectSid;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getOperatorSid() {
        return operatorSid;
    }

    public void setOperatorSid(String operatorSid) {
        this.operatorSid = operatorSid;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Long getSettlerId() {
        return settlerId;
    }

    public void setSettlerId(Long settlerId) {
        this.settlerId = settlerId;
    }
    public String getSettlerCode() {
        return settlerCode;
    }

    public void setSettlerCode(String settlerCode) {
        this.settlerCode = settlerCode;
    }
    public String getSettlerSid() {
        return settlerSid;
    }

    public void setSettlerSid(String settlerSid) {
        this.settlerSid = settlerSid;
    }
    public String getSettlerName() {
        return settlerName;
    }

    public void setSettlerName(String settlerName) {
        this.settlerName = settlerName;
    }
    
}

==> ejc-zdsmaterialb-impl-3.0.0-20251206.092326-106-sources.jar: com/ejianc/business/zdsmaterial/erp/bean/ContractManagerEntity.java <==
package com.ejianc.business.zdsmaterial.erp.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 合同负责人实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_material_erp_contract_manager_new")
public class ContractManagerEntity extends BaseEntity {

    private static final long serialVersionUID = -2800505942360815904L;

    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="modify_user_name")
    private String modifyUserName; // 修改人名称
    @TableField(value="contract_type")
    private String contractType; // 1-采购合同，2-分包合同
    @TableField(value="contract_id")
    private Long contractId; // 合同ID
    @TableField(value="contract_sid")
    private String contractSid; // 合同SID
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_sid")
    private String projectSid; // 项目SID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="operator_id")
    private Long operatorId; // 履约负责人ID
    @TableField(value="operator_code")
    private String operatorCode; // 履约负责人工号
    @TableField(value="operator_sid")
    private String operatorSid; // 履约负责人SID
    @TableField(value="operator_name")
    private String operatorName; // 履约负责人名称
    @TableField(value="settler_id")
    private Long settlerId; // 结算负责人ID
    @TableField(value="settler_code")
    private String settlerCode; // 结算负责人工号
    @TableField(value="settler_sid")
    private String settlerSid; // 结算负责人SID
    @TableField(value="settler_name")
    private String settlerName; // 结算负责人名称
    
    
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractSid() {
        return contractSid;
    }

    public void setContractSid(String contractSid) {
        this.contractSid = contractSid;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectSid() {
        return projectSid;
    }

    public void setProjectSid(String projectSid) {
        this.projectSid = projectSid;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getOperatorSid() {
        return operatorSid;
    }

    public void setOperatorSid(String operatorSid) {
        this.operatorSid = operatorSid;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Long getSettlerId() {
        return settlerId;
    }

    public void setSettlerId(Long settlerId) {
        this.settlerId = settlerId;
    }
    public String getSettlerCode() {
        return settlerCode;
    }

    public void setSettlerCode(String settlerCode) {
        this.settlerCode = settlerCode;
    }
    public String getSettlerSid() {
        return settlerSid;
    }

    public void setSettlerSid(String settlerSid) {
        this.settlerSid = settlerSid;
    }
    public String getSettlerName() {
        return settlerName;
    }

    public void setSettlerName(String settlerName) {
        this.settlerName = settlerName;
    }
    
}
